==> colorcode_0.5.5.orig.tar.gz: ColorCode/trans_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>About</name>
    <message>
        <source>&amp;Author</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A needful game to train your brain ;-)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ColorCode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About ColorCode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;br&gt;Free MasterMind clone including a built in,&lt;br&gt;rather intelligent solver.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Author</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ColorCode</name>
    <message>
        <source>New Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you want to give in
and start a new Game?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;New Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Restart Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The changed settings will only apply to new games!
Do you want to give in the current and start a new Game?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Place Your pegs ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Congratulation! You have won!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sorry! You lost!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Give In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you really want to give in?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Throw In The Towel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sure, You&apos;re too weak for me!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Shift+R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Shift+C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fill Row by Random</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate Previous Row</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear Row</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Row</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ColorCode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About &amp;ColorCode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Menubar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Statusbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow Pegs of the Same Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Computer&apos;s Guess</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Press the Hint Field or Key Enter if You&apos;re done.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disallow Pegs of the Same Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close Rows when the last Peg is placed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Beginner (2 Colors, 2 Slots, Doubles)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Easy (4 Colors, 3 Slots, No Doubles)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Classic (6 Colors, 4 Slots, Doubles)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Challenging (8 Colors, 4 Slots, Doubles)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hard (10 Colors, 5 Slots, Doubles)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Level Presets</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pegs of Same Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Slots</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset Color Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Letter Indicators</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Shift+L</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Online &amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>F1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RowHint</name>
    <message>
        <source>Commit Your solution</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> colorcode_0.6.1.orig.tar.gz: ColorCode/trans_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>About</name>
    <message>
        <source>&amp;Author</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A needful game to train your brain ;-)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ColorCode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About ColorCode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;br&gt;Free MasterMind clone including a built in,&lt;br&gt;rather intelligent solver.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Author</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ColorCode</name>
    <message>
        <source>New Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you want to give in
and start a new Game?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;New Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Restart Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The changed settings will only apply to new games!
Do you want to give in the current and start a new Game?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Place Your pegs ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Congratulation! You have won!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sorry! You lost!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Give In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you really want to give in?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Throw In The Towel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sure, You&apos;re too weak for me!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Shift+R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Shift+C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fill Row by Random</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate Previous Row</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear Row</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Row</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ColorCode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About &amp;ColorCode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Menubar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Statusbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow Pegs of the Same Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Computer&apos;s Guess</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Press the Hint Field or Key Enter if You&apos;re done.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disallow Pegs of the Same Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close Rows when the last Peg is placed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Beginner (2 Colors, 2 Slots, Doubles)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Easy (4 Colors, 3 Slots, No Doubles)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Classic (6 Colors, 4 Slots, Doubles)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Challenging (8 Colors, 4 Slots, Doubles)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hard (10 Colors, 5 Slots, Doubles)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Level Presets</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pegs of Same Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Slots</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset Color Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Shift+L</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Online &amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>F1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Done</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rate it for me</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Human vs Computer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Computer vs Human</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Press the button below or Key Enter if You&apos;re done.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Place Your secret ColorCode ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please rate the guess. Press OK or Key Enter if You&apos;re done.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The impossible happened, sorry.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yeah! I guessed it, man!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Embarrassing! I lost a game!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nope! Thats impossible! Did you gave me false hints?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t you like to see me winning? ;-)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Hints automatically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Shift+H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Indicators</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The chosen settings do not allow pegs of the same color!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PrefDialog</name>
    <message>
        <source>... Select from predefined level settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Beginner (2 Colors, 2 Slots, Doubles)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Easy (4 Colors, 3 Slots, No Doubles)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Classic (6 Colors, 4 Slots, Doubles)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Challenging (8 Colors, 4 Slots, Doubles)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hard (10 Colors, 5 Slots, Doubles)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Slots</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Human vs. Computer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Computer vs. Human</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Low</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Medium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>High</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Controls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show or hide the Menubar.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Menubar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show or hide the Toolbar.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show or hide the Statusbar.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Statusbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Indicators</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If this option is checked, an indicator
inside each peg is displayed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Indicators inside pegs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use unique letters as indicators.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Letter Indicators</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use unique numbers as indicators.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number Indicators</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use the same neutral background color for each peg,
when indicators are shown.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide Colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Click here if you have changed the color order
and now you want to revert it to it&apos;s initial state. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset Color Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Level Presets</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select from predefined combinations
of the three different level related settings,
the number of colors, the number of slots (columns)
and the possibility of pegs of the same color in one row. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of Slots</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of Colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of pegs in a single row.
Higher values are harder to guess.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of all possible colors.
Higher values are harder to guess.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If this option is checked, the hidden combination
may contain one or more (even all would be possible)
pegs of the same color.
If checked, the combination is generally harder to guess.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow Pegs of Same Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select from the different game modes.
In the 1. mode you have to to guess the hidden,
computer generated combination,
In the 2. mode your computer will try to guess your
own secret combination.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If checked, a row is closed as soon as you place the last peg
and your guess is submitted immediatly.
This option only affects the Human vs. Computer game mode.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close Rows when the last Peg is placed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If checked, the computer will determine the corresponding hints for the solver&apos;s guess.
This option affects only Computer vs. Human games.
If checked, you only have to place your secret combination.
Then the rest of the game runs automatically until the end.
But you can set a delay between the guesses.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Hints automatically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Adjust the delay (in ms) between two guesses.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delay in ms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Solver Strength</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select from 3 different strength levels for your computer opponent.
This option only affects the Computer vs. Human game mode.
For the computer&apos;s guess in the Human vs. Computer mode
always the highest level will be used.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RowHint</name>
    <message>
        <source>Commit Your solution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Click the circles to rate my guess.
Hit Ctrl+H or the corresponding toolbar button to let an impartial part of me do this for you ;-)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
